function val = FourierArray(x,n,a,b)
% FOURIERARRAY 
% Computes a matrix containing point values of the first n+1 Fourier
% polynomials (trigonimetric functions) cos(k*x), sin(k*x)
%  input: 
%     x = evaluation points (column vector)
%     n = the highest degree of the Legendre polynomials
%     a = left point of the reference interval
%     b = right point of the reference interval
% output:
%   val = columns of this matrix val(:,k) contain points values of 
%                 of the Fourier polynomials at evaluation points x
%
% Author: A. Chernov, alexey.chernov@uni-oldenburg.de
% Date: 28-04-2016

    if(nargin == 4)                           % transformation of x to 
        p = 0;                                % the reference interval [p,q]
        q = 2*pi;
        x = (q-p)/(b-a)*(x-(b+a)/2) + (p+q)/2;
    end

    val = repmat(x,1,n+1);

    val(:,1) = ones(size(x));
    
    for k=1:n+1
        val(:,k) = val(:,k) * floor(k/2);
    end
    
    val(:,1:2:end) = cos(val(:,1:2:end));
    val(:,2:2:end) = sin(val(:,2:2:end));      
end
