function [x,w]=GLquad(n,a,b)
% GLQUAD
% computes nodes x and weights w of Gauss-Legendre Quadrature Rule on [a,b]
% by solving a symmetric tridiagonal eigenwalue problem (Golub/Welsch 1969)
% 
%  input:  
%     n = number of quadrature pairs
%     a = left point of the interval
%     b = right point of the interval
% output:  
%     x = quardature nodes
%     w = quadrature weights
%
% Author: A. Chernov, alexey.chernov@uni-oldenburg.de
% Date: 28-04-2016

    c=1:n-1;                            % form the tridiagonal matrix J
    c=c./sqrt(4*c.*c-1);
    J=diag(c,-1)+diag(c,1); 

    [evec,eval]=eig(J);                 % find eigenvalues of J

    for i=1:n                           % normalize eigenvectors
        evec(:,i)=evec(:,i)./norm(evec(:,i));
    end

    x=diag(eval);                       % extract quadrature nodes
    w=(2*(evec(1,:).*evec(1,:)))';      % extract quadtature weights

    if(nargin == 3)                     % affine mapping [-1,1] -> [a,b]
        x = (b-a)/2*x + (b+a)/2;
        w = (b-a)/2*w;
    end
end
