function val = LegendrePArray(x,n,a,b)
% LEGENDREPARRAY 
% Computes a matrix containing point values of the first n+1 Legendre polynomials
%  input: 
%     x = evaluation points (column vector)
%     n = the highest degree of the Legendre polynomials
%     a = left point of the reference interval
%     b = right point of the reference interval
% output:
%   val = columns of this matrix val(:,k) contain values of 
%                the Legendre polynomial of degree k at evaluation points x
%
% Author: A. Chernov, alexey.chernov@uni-oldenburg.de
% Date: 28-04-2016

    if(nargin == 4)                          % transformation of x to 
        p = -1;                              % the reference interval [p,q]
        q = 1;
        x = (q-p)/(b-a)*(x-(b+a)/2) + (p+q)/2;
    end

    val = zeros(length(x),max(n,0)+1);       % allocate memory

    if(n >= 0)                               % initialize the 1st polynomial
        val(:,1) = ones(size(x));
    end 

    if(n >= 1)                               % initialize the 2nd polynomial
        val(:,2) = x;
    end

    if(n >= 2)                               % 3-term reccurence relation
        for k=1:n-1
            val(:,k+2) = ((2*k+1)*x.*val(:,k+1) - k*val(:,k))/(k+1);
        end
    end    
%     if(n >= 0)                             % optional orthonormalization
%         for k=1:n+1
%             val(:,k) = val(:,k)*sqrt(k-0.5);
%         end        
%     end    
end
