function val = MonomialsArray(x,n,a,b)
% MONOMIALSARRAY 
% Computes a matrix containing point values of the first n+1 monomials
%  input: 
%     x = evaluation points (column vector)
%     n = the highest degree of the Legendre polynomials
%     a = left point of the reference interval
%     b = right point of the reference interval
% output:
%   val = columns of this matrix val(:,k) contain values of 
%                the monomial of degree k at evaluation points x
%
% Author: A. Chernov, alexey.chernov@uni-oldenburg.de
% Date: 28-04-2016

    if(nargin == 4)                  % transformation of x to 
        p = 0;                       % the reference interval [p,q]
        q = 1;
        x = (q-p)/(b-a)*(x-(b+a)/2) + (p+q)/2;
    end

    val = zeros(length(x),max(n,0)+1);

    if(n >= 0)
        val(:,1) = ones(size(x));
    end 

    if(n >= 1)
        for k=1:n
            val(:,k+1) = val(:,k).*x;
        end
    end
      
end
